@@ -12,7 +12,7 @@ use std::process::Command;
 use std::sync::atomic::{AtomicU64, Ordering};
 use std::thread::sleep;
 use std::time::Duration;
-use sysinfo::{self, ProcessExt, SystemExt};
+use sysinfo::{ProcessExt, SystemExt};
 
 mod bandit;
 mod bench;
@@ -182,6 +182,7 @@ pub struct Config {
     pub enforce: EnforceConfig,
 
     pub sr_failed: MissedSysReqs,
+    sr_iosched: Option<String>,
     sr_wbt: Option<u64>,
     sr_wbt_path: Option<String>,
     sr_swappiness: Option<u32>,
@@ -444,6 +445,7 @@ impl Config {
             enforce: args.enforce.clone(),
 
             sr_failed: Default::default(),
+            sr_iosched: None,
             sr_wbt: None,
             sr_wbt_path: None,
             sr_swappiness: None,
@@ -751,6 +753,9 @@ impl Config {
 
         // mq-deadline scheduler
         if self.enforce.io {
+            if let Ok(v) = read_iosched(&self.scr_dev) {
+                self.sr_iosched = Some(v);
+            }
             if let Err(e) = set_iosched(&self.scr_dev, "mq-deadline") {
                 self.sr_failed.add(
                     SysReq::IoSched,
@@ -834,7 +839,7 @@ impl Config {
 
         // swap configuration check
         let swap_total = total_swap();
-        let swap_avail = swap_total - sys.get_used_swap() as usize * 1024;
+        let swap_avail = swap_total - sys.used_swap() as usize * 1024;
 
         if (swap_total as f64) < (total_memory() as f64 * 0.3) {
             self.sr_failed.add(
@@ -918,7 +923,7 @@ impl Config {
         // Gotta re-read sysinfo to avoid reading cached oomd pid from
         // before stopping it.
         let sys = sysinfo::System::new();
-        let procs = sys.get_processes();
+        let procs = sys.processes();
         for (pid, proc) in procs {
             let exe = proc
                 .exe()
@@ -993,9 +998,7 @@ impl Config {
         SysReqsReport {
             satisfied: &*ALL_SYSREQS_SET ^ &self.sr_failed.map.keys().copied().collect(),
             missed: self.sr_failed.clone(),
-            kernel_version: sys
-                .get_kernel_version()
-                .expect("Failed to read kernel version"),
+            kernel_version: sys.kernel_version().expect("Failed to read kernel version"),
             agent_version: FULL_VERSION.to_string(),
             hashd_version,
             nr_cpus: nr_cpus(),
@@ -1032,6 +1035,11 @@ impl Config {
 
 impl Drop for Config {
     fn drop(&mut self) {
+        if let Some(iosched) = self.sr_iosched.as_ref() {
+            if let Err(e) = set_iosched(&self.scr_dev, iosched) {
+                error!("cfg: Failed to restore iosched to {:?} ({:#})", iosched, &e);
+            }
+        }
         if let Some(wbt) = self.sr_wbt {
             let path = self.sr_wbt_path.as_ref().unwrap();
             info!("cfg: Restoring {:?} to {}", path, wbt);
